@@ -1,3 +1,6 @@
+#[cfg(any(feature = "google-cloud-notebooks-logging-v1",))]
+pub mod logging;
+
 #[cfg(any(feature = "google-cloud-notebooks-v1",))]
 pub mod v1;
 
